@@ -19,8 +19,6 @@ WARRANTIES, see the file, "license.txt," in this distribution.
 
 #include "flpushns.h"
 
-#if FLEXT_SYS != FLEXT_SYS_JMAX
-
 #if FLEXT_SYS == FLEXT_SYS_PD
 #define DIRTY_INTERVAL 0   // buffer dirty check in msec
 
@@ -397,8 +395,6 @@ FLEXT_TEMPIMPL(bool FLEXT_CLASSDEF(flext))::buffer::IsDirty() const
 #endif
 }
 
-#endif // Jmax
-
 #include "flpopns.h"
 
 #endif // __FLEXT_BUF_CPP
